pub struct ProcessInfo {
pub pid: i32,
pub comm: String,
pub cmdline: String,
pub stat: Stat,
pub euid: u32,
pub ruid: u32,
pub rgid: u32,
}Expand description
Per-process snapshot built up while walking /proc. Carries the
fields filters operate on (PID, comm/cmdline, real/effective UID
and GID), plus the underlying procfs::process::Stat for tools
that need additional fields like start time or process group.
Fields
pid: i32comm: Stringcmdline: Stringstat: Stateuid: u32ruid: u32rgid: u32Implementations
Sourceimpl ProcessInfo
impl ProcessInfo
Sourcepub fn match_text(&self, full: bool) -> &str
pub fn match_text(&self, full: bool) -> &str
Returns the text the regex pattern should be matched against —
the full command line if full is true (corresponds to -f),
otherwise the comm field.